@@ -7,8 +7,6 @@ fn test_cell()
 
     #[cfg(feature = "use_sync")]
     use syslog_rs::sy_sync::{Syslog};
-    #[cfg(feature = "use_sync_queue")]
-    use syslog_rs::sy_sync_queue::{Syslog};
     use syslog_rs::{LogStat, LogFacility, Priority, UnsafeReadOnlyCell};
 
     lazy_static! {
